@@ -173,7 +173,7 @@ class Debugger(bdb.Bdb):
         # Start with fresh empty copy of globals and locals and tell the script
         # that it's being run as __main__ to avoid scripts being able to access
         # the debugger's namespace.
-        globals_ = {"__name__" : "__main__"}
+        globals_ = {"__name__" : "__main__", "__file__": filename }
         locals_ = globals_
 
         # When bdb sets tracing, a number of call and line events happens
@@ -411,7 +411,7 @@ class SearchBox(urwid.Edit):
 
 
 class DebuggerUI(object):
-    CAPTION_TEXT = (u"PuDB - The Python Urwid debugger - F1 for help"
+    CAPTION_TEXT = (u"PuDB - The Python Urwid debugger - Hit ? for help"
             u" - © Andreas Klöckner 2009")
 
     def __init__(self, dbg):
@@ -943,6 +943,14 @@ class DebuggerUI(object):
     def event_loop(self, toplevel=None):
         prev_quit_loop = self.quit_event_loop
 
+        try:
+            import pygments
+        except ImportError:
+            if not hasattr(self, "pygments_message_shown"):
+                self.pygments_message_shown = True
+                self.message("Package 'pygments' not found. "
+                        "Syntax highlighting disabled.")
+
         try:
             if toplevel is None:
                 toplevel = self.top
